@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 from django.conf.urls import patterns, include, url
 from rest_framework import routers
-from api import views
+from shiori.api import views
 
 router = routers.DefaultRouter(trailing_slash=False)
 router.register(r'categories', views.CategoryViewSet)
